using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public struct Attribute
{
    [SerializeField]
    private long _base;

    public Attribute(long stat)
    {
        _base = stat;
    }

    /// <summary>
    /// Permanently increase the stat value.
    /// </summary>
    /// <param name="by">Increase amount.</param>
    public void LevelUp(long by)
    {
        _base += by;
    }

    /// <summary>
    /// Calculates the stat value with accumulated buff and debuff modifiers.
    /// </summary>
    /// <param name="baseBonus">Additive bonus applied before multiplicative scaling.</param>
    /// <param name="permyriadBonus">Multiplicative scaling in hundredths of a percent. E.g., 625 permyriad corresponds to 6.25%.</param>
    /// <param name="flatBonus">Additive bonus applied after multiplicative scaling.</param>
    /// <returns>(base + baseBonus) * (100% + permyriadBonus) + flatBonus, bounded below by 0.</returns>
    public long Calc(long baseBonus, long permyriadBonus, long flatBonus)
    {
        var r = _base + baseBonus;
        var m = permyriadBonus + 10000;
        r = r * (m / 10000) + (r / 10000) * (m % 10000) + flatBonus;
        if (r <= 0)
        {
            return 0;
        }
        return r;
    }
}
